Enum ImeSurroundingTextError
pub enum ImeSurroundingTextError {
TextTooLong,
CursorBadPosition,
AnchorBadPosition,
}Variants
TextTooLong
Text exceeds 4000 bytes
CursorBadPosition
Cursor not on a code point boundary, or past the end of text.
AnchorBadPosition
Anchor not on a code point boundary, or past the end of text.