Struct ImeEnableRequest
pub struct ImeEnableRequest { /* private fields */ }Expand description
Initial IME request.
Implementations
impl ImeEnableRequest
impl ImeEnableRequest
pub fn new(
capabilities: ImeCapabilities,
request_data: ImeRequestData,
) -> Option<ImeEnableRequest>
pub fn new( capabilities: ImeCapabilities, request_data: ImeRequestData, ) -> Option<ImeEnableRequest>
Create request for the ImeRequest::Enable
This will return None if some capability was requested but its initial value was not
set by the user or value was set by the user, but capability not requested.
pub const fn capabilities(&self) -> &ImeCapabilities
pub const fn capabilities(&self) -> &ImeCapabilities
ImeCapabilities to enable.
pub const fn request_data(&self) -> &ImeRequestData
pub const fn request_data(&self) -> &ImeRequestData
Request data attached to request.
pub fn into_raw(self) -> (ImeCapabilities, ImeRequestData)
pub fn into_raw(self) -> (ImeCapabilities, ImeRequestData)
Destruct ImeEnableRequest into its raw parts.