Struct ImeHint
#[non_exhaustive]pub struct ImeHint(/* private fields */);Expand description
IME hints
The hint should reflect the desired behaviour of the IME
while entering text.
The purpose may improve UX by optimizing the IME for the specific use case,
beyond just the general data type specified in ImePurpose.
Platform-specific
- iOS / Android / Web / Windows / X11 / macOS / Orbital: Unsupported.
Implementations
impl ImeHint
impl ImeHint
pub const COMPLETION: ImeHint
pub const COMPLETION: ImeHint
Suggest word completions.
pub const SPELLCHECK: ImeHint
pub const SPELLCHECK: ImeHint
Suggest word corrections.
pub const AUTO_CAPITALIZATION: ImeHint
pub const AUTO_CAPITALIZATION: ImeHint
Switch to uppercase letters at the start of a sentence.
pub const HIDDEN_TEXT: ImeHint
pub const HIDDEN_TEXT: ImeHint
Characters should be hidden.
This may prevent e.g. layout switching with some IMEs, unless hint is disabled.
pub const SENSITIVE_DATA: ImeHint
pub const SENSITIVE_DATA: ImeHint
Typed text should not be stored.
impl ImeHint
impl ImeHint
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<ImeHint>
pub const fn from_bits(bits: u32) -> Option<ImeHint>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> ImeHint
pub const fn from_bits_truncate(bits: u32) -> ImeHint
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> ImeHint
pub const fn from_bits_retain(bits: u32) -> ImeHint
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<ImeHint>
pub fn from_name(name: &str) -> Option<ImeHint>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: ImeHint) -> bool
pub const fn intersects(&self, other: ImeHint) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: ImeHint) -> bool
pub const fn contains(&self, other: ImeHint) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: ImeHint)
pub fn remove(&mut self, other: ImeHint)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: ImeHint, value: bool)
pub fn set(&mut self, other: ImeHint, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: ImeHint) -> ImeHint
pub const fn intersection(self, other: ImeHint) -> ImeHint
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: ImeHint) -> ImeHint
pub const fn union(self, other: ImeHint) -> ImeHint
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: ImeHint) -> ImeHint
pub const fn difference(self, other: ImeHint) -> ImeHint
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: ImeHint) -> ImeHint
pub const fn symmetric_difference(self, other: ImeHint) -> ImeHint
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> ImeHint
pub const fn complement(self) -> ImeHint
The bitwise negation (!) of the bits in self, truncating the result.
impl ImeHint
impl ImeHint
pub const fn iter(&self) -> Iter<ImeHint>
pub const fn iter(&self) -> Iter<ImeHint>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<ImeHint>
pub const fn iter_names(&self) -> IterNames<ImeHint>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.