Struct ImeCapabilities
pub struct ImeCapabilities(/* private fields */);Expand description
IME capabilities supported by client.
For example, if the client doesn’t support ImeCapabilities::cursor_area(), then not enabling
it will make IME hide the popup window instead of placing it arbitrary over the
client’s window surface.
When the capability is not enabled or not supported by the IME, trying to update its’
corresponding data with ImeRequest will be ignored.
New capabilities may be added to this struct in the future.
Implementations
impl ImeCapabilities
impl ImeCapabilities
pub fn new() -> ImeCapabilities
pub fn new() -> ImeCapabilities
Returns a new empty set of capabilities.
pub const fn with_hint_and_purpose(self) -> ImeCapabilities
pub const fn with_hint_and_purpose(self) -> ImeCapabilities
Marks hint and purpose as supported.
For more details see ImeRequestData::with_hint_and_purpose.
pub const fn without_hint_and_purpose(self) -> ImeCapabilities
pub const fn without_hint_and_purpose(self) -> ImeCapabilities
Marks hint and purpose as unsupported.
For more details see ImeRequestData::with_hint_and_purpose.
pub const fn hint_and_purpose(&self) -> bool
pub const fn hint_and_purpose(&self) -> bool
Returns true if hint and purpose is supported.
pub const fn with_cursor_area(self) -> ImeCapabilities
pub const fn with_cursor_area(self) -> ImeCapabilities
Marks cursor_area as supported.
For more details see ImeRequestData::with_cursor_area.
pub const fn without_cursor_area(self) -> ImeCapabilities
pub const fn without_cursor_area(self) -> ImeCapabilities
Marks cursor_area as unsupported.
For more details see ImeRequestData::with_cursor_area.
pub const fn cursor_area(&self) -> bool
pub const fn cursor_area(&self) -> bool
Returns true if cursor_area is supported.
pub const fn with_surrounding_text(self) -> ImeCapabilities
pub const fn with_surrounding_text(self) -> ImeCapabilities
Marks surrounding_text as supported.
For more details see ImeRequestData::with_surrounding_text.
pub const fn without_surrounding_text(self) -> ImeCapabilities
pub const fn without_surrounding_text(self) -> ImeCapabilities
Marks surrounding_text as unsupported.
For more details see ImeRequestData::with_surrounding_text.
pub const fn surrounding_text(&self) -> bool
pub const fn surrounding_text(&self) -> bool
Returns true if surrounding_text is supported.